@@ -2,16 +2,34 @@ package Alien::gdal;
 
 use strict;
 use warnings;
-use base qw( Alien::Base );
+use parent qw( Alien::Base );
 
-our $VERSION = '1.05';
+our $VERSION = '1.07';
 
 sub data_dir {
-    my $self = shift;    
-    
+    my $self = shift;
+ 
     my $path = $self->dist_dir . '/share/gdal';
-    die "Cannot find gdal share dir"
-      if !-d $path;
+    
+    if (!-d $path) {
+        #  try PkgConfig
+        use PkgConfig;
+        my %options;
+        if (-d $self->dist_dir . '/lib/pkgconfig') {
+            $options{search_path_override} = [$self->dist_dir . '/lib/pkgconfig'];
+        }
+        my $o = PkgConfig->find('gdal', %options);
+        if ($o->errmsg) {
+            warn $o->errmsg;       
+        }
+        else {
+            $path = $o->get_var('datadir');
+        }
+    }
+
+    warn "Cannot find gdal data dir"
+      if not (defined $path and -d $path);
+
     return $path;
 }
 
@@ -44,9 +62,12 @@ Alien::gdal - Compile gdal, the Geographic Data Abstraction Library
 
     print Alien::gdal->dist_dir;
 
-    #  example assumes @args exists already
+    #  assuming you have populated @args already
     system (Alien::gdal->bin_dir, 'gdalwarp', @args);
     
+    #  access the example data distributed with gdal
+    my $path = Alien::gdal->data_dir;
+    
 =head1 DESCRIPTION
 
 GDAL is the Geographic Data Abstraction Library.  See L<http://www.gdal.org>.
